@@ -16,6 +16,7 @@ make_prophet_reg <- function() {
     # * Model ----
     parsnip::set_model_engine("prophet_reg", mode = "regression", eng = "prophet")
     parsnip::set_dependency("prophet_reg", eng = "prophet", pkg = "prophet")
+    parsnip::set_dependency("prophet_reg", eng = "prophet", pkg = "modeltime")
 
     # * Args ----
     parsnip::set_model_arg(
@@ -30,9 +31,45 @@ make_prophet_reg <- function() {
     parsnip::set_model_arg(
         model        = "prophet_reg",
         eng          = "prophet",
-        parsnip      = "num_changepoints",
+        parsnip      = "changepoint_num",
         original     = "n.changepoints",
-        func         = list(pkg = "modeltime", fun = "num_changepoints"),
+        func         = list(pkg = "modeltime", fun = "changepoint_num"),
+        has_submodel = FALSE
+    )
+
+    parsnip::set_model_arg(
+        model        = "prophet_reg",
+        eng          = "prophet",
+        parsnip      = "changepoint_range",
+        original     = "changepoint.range",
+        func         = list(pkg = "modeltime", fun = "changepoint_range"),
+        has_submodel = FALSE
+    )
+
+    parsnip::set_model_arg(
+        model        = "prophet_reg",
+        eng          = "prophet",
+        parsnip      = "seasonality_yearly",
+        original     = "yearly.seasonality",
+        func         = list(pkg = "modeltime", fun = "seasonality_yearly"),
+        has_submodel = FALSE
+    )
+
+    parsnip::set_model_arg(
+        model        = "prophet_reg",
+        eng          = "prophet",
+        parsnip      = "seasonality_weekly",
+        original     = "weekly.seasonality",
+        func         = list(pkg = "modeltime", fun = "seasonality_weekly"),
+        has_submodel = FALSE
+    )
+
+    parsnip::set_model_arg(
+        model        = "prophet_reg",
+        eng          = "prophet",
+        parsnip      = "seasonality_daily",
+        original     = "daily.seasonality",
+        func         = list(pkg = "modeltime", fun = "seasonality_daily"),
         has_submodel = FALSE
     )
 
@@ -72,6 +109,24 @@ make_prophet_reg <- function() {
         has_submodel = FALSE
     )
 
+    parsnip::set_model_arg(
+        model        = "prophet_reg",
+        eng          = "prophet",
+        parsnip      = "logistic_cap",
+        original     = "logistic_cap",
+        func         = list(pkg = "modeltime", fun = "logistic_cap"),
+        has_submodel = FALSE
+    )
+
+    parsnip::set_model_arg(
+        model        = "prophet_reg",
+        eng          = "prophet",
+        parsnip      = "logistic_floor",
+        original     = "logistic_floor",
+        func         = list(pkg = "modeltime", fun = "logistic_floor"),
+        has_submodel = FALSE
+    )
+
     # * Encoding ----
     parsnip::set_encoding(
         model   = "prophet_reg",
